@@ -9,6 +9,12 @@
 #define MODE_WR 1
 #define MODE_EX 2
 
+#if defined(PERL_VERSION) && PERL_VERSION > 9
+#define POE_SV_FORMAT "%-p"
+#else
+#define POE_SV_FORMAT "%_"
+#endif
+
 extern void
 poe_enqueue_data_ready(SV *kernel, int mode, int *fds, int fd_count);
 
@@ -27,6 +33,9 @@ poe_timeh(void);
 extern const char *
 poe_mode_names(int mode);
 
+extern void
+poe_trap(const char *fmt, ...);
+
 #ifdef XS_LOOP_TRACE
 #include <stdio.h>
 #include <stdarg.h>
@@ -52,6 +61,4 @@ poexs_data_stat_add(SV *kernel, const char *name, double value);
 #define POE_STAT_ADD(kernel, name, value)
 #endif
 
-
-
 #endif
